@@ -8,6 +8,7 @@ This provides a simply class that can be used to query the Github GraphQL API.
 
 from typing import Dict, Union
 from requests import Session
+from requests.structures import CaseInsensitiveDict
 from .result import Result
 
 
@@ -34,6 +35,12 @@ class GithubGraphQL:
         self.__token = token
         self.__encoding = "utf-8"
         self.__session = Session()
+        self.__session.headers.update({
+            "Authorization": f"Bearer {self.token}",
+            # See #
+            # https://github.blog/2021-11-16-graphql-global-id-migration-update/
+            'X-Github-Next-Global-ID': '1'
+        })
 
     @property
     def token(self) -> str:
@@ -65,17 +72,16 @@ class GithubGraphQL:
         """
         with open(file=filename, mode="r", encoding=self.encoding) as file_handle:
             query = file_handle.read()
-        return self.__query(query, variables)
+        return self.query(query, variables)
 
     def __enter__(self):
-        self.__session.headers.update({
-            "Authorization": f"Bearer {self.token}",
-            # See #
-            # https://github.blog/2021-11-16-graphql-global-id-migration-update/
-            'X-Github-Next-Global-ID': '1'
-        })
         return self
 
+    @property
+    def session_headers(self) -> CaseInsensitiveDict:
+        """ Returns the HTTP headers used for the session. """
+        return self.__session.headers
+
     def __exit__(self, exc_type, exc_value, traceback):
         self.close()
 
@@ -83,19 +89,15 @@ class GithubGraphQL:
         """ Closes the session. """
         self.__session.close()
 
-    def __query(self,
-                query: str,
-                variables: Dict[str,
-                                Union[str,
-                                      int]] = None) -> Result:
+    def query(self,
+              query: str,
+              variables: Dict[str,
+                              Union[str,
+                                    int]] = None) -> Result:
         """
         Execute the query with the variables applied. An exception is raised if
         there's an error; otherwise the result data is returned.
 
-        NOTE: We explicitly made this method private because we want to make it
-              a habit to use files instead of query strings. Those query files
-              can be tested and validated more easily.
-
         Args:
             query (str): The GraphQL query.
             variables (dict): The variables to be applied to the query.
